<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) )
	exit;

/**
 *	WPCasa_Legacy_Admin_CPT class
 */
class WPCasa_Legacy_Admin_CPT {

	/**
	 *	Constructor
	 */
	public function __construct() {

		// Manage custom columns on properties screen

		add_filter( 'manage_edit-property_columns', array( $this, 'columns' ) );
		add_action( 'manage_property_posts_custom_column', array( $this, 'custom_columns' ), 2 );
		add_filter( 'manage_edit-property_sortable_columns', array( $this, 'sortable_columns' ) );
		
	}
	
	/**
	 *	columns()
	 *	
	 *	Define columns for manage_edit-property_columns filter.
	 *	
	 *	@access	public
	 *	@param	mixed	$columns
	 *	
	 *	@since 1.0.0
	 */
	public function columns( $columns ) {
		
		// Make sure we deal with array

		if ( ! is_array( $columns ) )
			$columns = array();

		// Unset some default columns
		unset( $columns['title'], $columns['date'], $columns['author'] );

		// Define our custom columns

		$columns["listing_offer"]	= __( 'Offer', 'wpcasa' );
		$columns["listing_id"]		= __( 'ID', 'wpcasa' );
		$columns["listing_title"]	= __( 'Listing', 'wpcasa' );
		$columns["listing_price"]	= __( 'Price', 'wpcasa' );
		$columns["listing_posted"]	= __( 'Posted', 'wpcasa' );
		
		if( class_exists( 'WPSight_Expire_Listings' ) )
			$columns["listing_expires"]	= __( 'Expires', 'wpcasa' );

		$columns['listing_status']	= __( 'Status', 'wpcasa' );;
		$columns['listing_actions']	= __( 'Actions', 'wpcasa' );

		return apply_filters( 'wpsight_admin_listing_columns', $columns );

	}

	/**
	 *	custom_columns()
	 *	
	 *	Define custom columns for
	 *	manage_property_posts_custom_column action.
	 *	
	 *	@access	public
	 *	@param	mixed	$column
	 *	@uses	wpsight_get_option()
	 *	@uses	wpsight_get_listing_offer()
	 *	@uses	wpsight_get_offer_color()
	 *	@uses	wpsight_get_offer()
	 *	@uses	wpsight_listing_id()
	 *	@uses	wpsight_listing_price()
	 *	@uses	wpsight_get_listing_thumbnail()
	 *	@uses	wpsight_is_listing_sticky()
	 *	@uses	wpsight_is_listing_featured()
	 *	@uses	wpsight_get_listing_terms()
	 *	@uses	wpsight_is_listing_not_available()
	 *	@uses	current_user_can()
	 *	@uses	wpsight_get_listing_summary()
	 *	@uses	wpsight_is_listing_pending()
	 *	@uses	wpsight_is_listing_expired()
	 *	@uses	wpsight_is_listing_sticky()
	 *	@uses	wpsight_sort_array_by_priority()
	 *	
	 *	@since 1.0.0
	 */
	public function custom_columns( $column ) {
		global $post;
		
		$datef = wpsight_get_option( 'date_format', get_option( 'date_format' ) );

		switch ( $column ) {

			case "listing_offer" :

				// Get listing offer (sale, rent etc.)
				$listing_offer = wpsight_get_listing_offer( $post->ID, false );
				
				// Display colored offer badge
				
				if ( $listing_offer )
					echo '<span style="background-color:' . esc_attr( wpsight_get_offer_color( $listing_offer ) ) . '" class="' . sanitize_html_class( $listing_offer ) . '">' . esc_attr( wpsight_get_offer( $listing_offer ) ) . '</span>';

			break;
			
			case "listing_id" :
			
				// Disply listing ID
				wpsight_listing_id( $post->ID );

			break;
			
			case "listing_price" :
			
				// Display listing price
				wpsight_listing_price( $post->ID );

			break;

			case "listing_title" :
			
				// Display listing thumbnail (with edit link if not in trash)
				
				if ( $post->post_status !== 'trash' && current_user_can( 'edit_listing', $post->ID ) ) {
					echo '<a href="' . get_edit_post_link( $post->ID ) . '">' . wpsight_get_listing_thumbnail( $post->ID ) . '</a>';
				} else {							
					echo wpsight_get_listing_thumbnail( $post->ID );							
				}
			
				echo '<div class="listing-info">';

					echo '<div class="listing-title">';
					
						// Display listing title (with edit link if not in trash)
						
						if ( $post->post_status !== 'trash' && current_user_can( 'edit_listing', $post->ID ) ) {
							echo '<a href="' . admin_url( 'post.php?post=' . $post->ID . '&action=edit') . '" class="tips" data-tip="' . __( 'Edit', 'wpcasa' ) . '">' . $post->post_title . '</a>';
						} else {							
							echo $post->post_title;							
						}
						
						if ( $post->post_status !== 'trash' && class_exists( 'WPSight_Featured_Listings' ) ) {
						
							// Display sticky
						
							if( wpsight_is_listing_sticky() )
								echo ' <span class="listing-sticky">&dash; ' . __( 'Sticky', 'wpcasa' ) . '</span>';
							
							// Display featured
							
							if( wpsight_is_listing_featured() )
								echo ' <span class="listing-featured">&dash; ' . __( 'Featured', 'wpcasa' ) . '</span>';
						
						}
						
					echo '</div>';
					
					echo '<div class="listing-taxonomies">';
					
						$type 	  = wpsight_get_listing_terms( 'property-type' );
						$location = wpsight_get_listing_terms( 'location' );
					
						// Display listing type terms
						
						if( $type ) {
							echo '<div class="listing-type">';
								echo wpsight_get_listing_terms( 'property-type', $post->ID, ', ', '', '', false );
							echo '</div>';
						}
						
						if( $type && $location )
							echo '&dash; ';
						
						// Display listing location terms
					
						if( $location ) {
							echo '<div class="location">';
								echo wpsight_get_listing_terms( 'location', $post->ID, ' &rsaquo; ', '', '', false );
							echo '</div>';
						}
					
					echo '</div>';
					
					// Display text if item not available
					
					if( wpsight_is_listing_not_available() )
						echo '<span class="listing-not-available">' . __( 'Item is currently not available', 'wpcasa' ) . '</span>';
					
					// Display listing title actions (edit, view)
					
					echo '<div class="actions">';
				
						$admin_actions_listing_title = array();
						
						if( current_user_can( 'edit_listing', $post->ID ) ) {
						
							if ( $post->post_status !== 'trash' ) {
							
								$admin_actions_listing_title['edit']   = array(
									'action'  => 'edit',
									'name'    => __( 'Edit', 'wpcasa' ),
									'url'     => get_edit_post_link( $post->ID )
								);
							
								$admin_actions_listing_title['view']   = array(
									'action'  => 'view',
									'name'    => __( 'View', 'wpcasa' ),
									'url'     => get_permalink( $post->ID ),
									'target'  => '_blank'
								);
							
							}
						
						}
						
						$admin_actions_listing_title = apply_filters( 'wpsight_admin_actions_listing_title', $admin_actions_listing_title, $post );
						
						foreach ( $admin_actions_listing_title as $action ) {
							printf( '<a class="button tips" href="%2$s" data-tip="%3$s" target="%5$s"><i class="icon icon-%1$s"></i> %4$s</a>', $action['action'], esc_url( $action['url'] ), esc_attr( $action['name'] ), esc_html( $action['name'] ), isset( $action['target'] ) ? esc_html( $action['target'] ) : false );
						}
					
					echo '</div>';
					
					// Display more info when excerpt list mode
					
					if( isset( $_REQUEST['mode'] ) && $_REQUEST['mode'] == 'excerpt' ) {						
					
						echo '<div class="listing-summary">';						
							echo '<p>' . wpsight_get_listing_summary() . '</p>';						
						echo '</div>';
						
						echo '<div class="listing-excerpt">';						
							echo '<p>' . wp_trim_excerpt() . '</p>';						
						echo '</div>';
						
					}
				
				echo '</div>';

			break;
			
			case "listing_status" :
				
				// Display listing status (e.g. pending, active) with colored dot
				echo '<span class="listing-status status-' . sanitize_html_class( $post->post_status ) . '"><span></span> ' . wpsight_get_status( $post->post_status ) . '</span>';

			break;

			case "listing_posted" :
			
				// Display listing publish date
				echo '<span class="listing-posted">' . date_i18n( $datef, strtotime( $post->post_date ) ) . '</span>';
				
				$user_name = current_user_can( 'edit_users' ) ? '<a href="' . get_edit_user_link( $post->post_author ) . '">' . get_the_author() . '</a>' : get_the_author();
				
				// Display listing agent
				echo '<span class="listing-agent">' . ( empty( $post->post_author ) ? __( 'by a guest', 'wpcasa' ) : sprintf( __( 'by %s', 'wpcasa' ), $user_name ) ) . '</span>';

			break;

			case "listing_actions" :
			
				// Define some general classes to be used with action buttons
			
				$classes = array();
				
				if( ! wpsight_is_listing_pending( $post->ID ) )
					$classes[] = 'listing-approved';
				
				if( wpsight_is_listing_expired( $post->ID ) )
					$classes[] = 'listing-expired';
			
				if( wpsight_is_listing_not_available( $post->ID ) )
					$classes[] = 'listing-not-available';
				
				if( wpsight_is_listing_sticky( $post->ID ) )
					$classes[] = 'listing-sticky';
				
				if( wpsight_is_listing_featured( $post->ID ) )
					$classes[] = 'listing-featured';
				
				// Display action buttons
			
				echo '<div class="actions ' . join( ' ', $classes ) . '">';
				
					$admin_actions = array();
					
					if ( $post->post_status !== 'trash' ) {
						
						$admin_actions['approve']   = array(
							'action'   => 'approve',
							'name'     => wpsight_is_listing_pending( $post->ID ) ? __( 'Approve', 'wpcasa' ) : __( 'Unapprove', 'wpcasa' ),
							'url'      =>  wp_nonce_url( add_query_arg( 'approve_listing', $post->ID ), 'approve_listing' ),
							'cap'	   => 'publish_listings',
							'priority' => 10
						);
						
						$admin_actions['unavailable']   = array(
							'action'   => 'unavailable',
							'name'     => wpsight_is_listing_not_available( $post->ID ) ? __( 'Mark available', 'wpcasa' ) : __( 'Mark unavailable', 'wpcasa' ),
							'url'      =>  wp_nonce_url( add_query_arg( 'toggle_unavailable', $post->ID ), 'toggle_unavailable' ),
							'cap'	   => 'publish_listings',
							'priority' => 20
						);
					
						$admin_actions['delete'] = array(
							'action'   => 'delete',
							'name'     => __( 'Trash', 'wpcasa' ),
							'url'      => get_delete_post_link( $post->ID ),
							'cap'	   => 'delete_listing',
							'priority' => 30
						);
					
					} else {
					
						$admin_actions['untrash'] = array(
							'action'   => 'untrash',
							'name'     => __( 'Restore', 'wpcasa' ),
							'url'      => wp_nonce_url( admin_url( 'post.php?post=' . $post->ID . '&action=untrash' ), 'untrash-post_' . $post->ID ),
							'cap'	   => 'delete_listing',
							'priority' => 10
						);
					
					}
					
					$admin_actions = apply_filters( 'wpsight_admin_actions', $admin_actions, $post );
					
					// Sort array by priority
					$admin_actions = wpsight_sort_array_by_priority( $admin_actions );
						
					$i = 0;
					
					foreach ( $admin_actions as $action ) {
						
						$action['cap'] = isset( $action['cap'] ) ? $action['cap'] : 'read_listing';
						
						if( current_user_can( $action['cap'], $post->ID ) ) {
						
							printf( '<a class="button tips" href="%2$s" data-tip="%3$s" target="%5$s"><i class="icon icon-%1$s"></i> %4$s</a>', $action['action'], esc_url( $action['url'] ), esc_attr( $action['name'] ), esc_html( $action['name'] ), isset( $action['target'] ) ? esc_html( $action['target'] ) : false );
							
							$i++;
						
						}

					}
					
					// If no other action is displayed, show view button
					
					if( 0 == $i && $post->post_status == 'publish' )
						printf( '<a class="button tips" href="%2$s" data-tip="%3$s" target="%5$s"><i class="icon icon-view"></i> %4$s</a>', 'view', esc_url( get_permalink( $post->ID ) ), esc_attr( __( 'View', 'wpcasa' ) ), esc_html( __( 'View', 'wpcasa' ) ), '_blank' );

				echo '</div>';

			break;

		}
		
	}

	/**
	 *	sortable_columns()
	 *	
	 *	Define some sortable columns for
	 *	manage_edit-property_sortable_columns filter.
	 *	
	 *	@access	public
	 *	@param	mixed	$columns
	 *	@uses	wp_parse_args()
	 *	
	 *	@since 1.0.0
	 */
	public function sortable_columns( $columns ) {

		$custom = array(
			'listing_id'   		=> 'listing_id',
			'listing_title'   	=> 'title',
			'listing_price' 	=> 'listing_price',
			'listing_posted'  	=> 'date'
		);

		return wp_parse_args( $custom, $columns );

	}
    
}
