<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) )
	exit;

/**
 * WPCasa_Legacy_Post_Type_Property class
 */
class WPCasa_Legacy_Post_Type_Property {

	/**
	 * Constructor
	 */
	public function __construct() {
		
		// Let helper classes know about new post type and taxnomoies
				
		add_filter( 'wpsight_post_type', array( $this, 'post_type' ) );
		add_filter( 'wpsight_taxonomies', array( $this, 'taxonomies' ), 10, 2 );
		
		// Let property use listing template
		add_filter( 'single_template', array( $this, 'single_template' ), 10, 3 );
		
		// Set body class on single property pages
		add_filter( 'body_class', array( $this, 'body_class' ) );
		
		// Remove listing post type and taxonomies
		add_action( 'init', array( $this, 'remove_post_type_and_taxonomies' ) );
		
		// Register property post type
		add_action( 'init', array( $this, 'register_post_type_property' ), 0 );

	}
	
	/**
	 *	post_type()
	 *
	 *  Set post type to be returned by wpsight_post_type().
	 *
	 *	@since 1.0.0
	 */
	public function post_type() {		
		return 'property';
	}
	
	/**
	 *	taxonomies()
	 *
	 *  Filter wpsight_taxonomies().
	 *
	 *	@since 1.0.0
	 */
	public function taxonomies( $taxonomies, $output ) {
		
		if( 'objects' == $output ) {
		
			// Unset listing type
			
			if( isset( $taxonomies['listing-type'] ) )
				unset( $taxonomies['listing-type'] );
			
			// Unset listing category
			
			if( isset( $taxonomies['listing-category'] ) )
				unset( $taxonomies['listing-category'] );
			
			// Add property type
			$taxonomies['property-type'] = get_taxonomy( 'property-type' );
			
			// Add property category
			$taxonomies['property-category'] = get_taxonomy( 'property-category' );
		
		} elseif( 'names' == $output ) {
			
			// Replace listing tye with property type
			
			if( ( $key_type = array_search( 'listing-type', $taxonomies ) ) !== false )
				$taxonomies[ $key_type ] = 'property-type';
			
			// Replace listing category with property category
			
			if( ( $key_cat = array_search( 'listing-category', $taxonomies ) ) !== false )
				$taxonomies[ $key_cat ] = 'property-category';
			
		}
		
		return $taxonomies;
		
	}
	
	/**
	 *	body_class()
	 *
	 *  Add single-listing to single
	 *	property page body class.
	 *
	 *	@since 1.0.0
	 */
	public function body_class( $classes ) {		
		
		if( wpsight_is_listing_single() )
			$classes[] = 'single-listing';
		
		return $classes;
		
	}
	
	/**
	 *	single_template()
	 *
	 *  Let single property look for
	 *	single-listing.php template.
	 *
	 *	@since 1.0.0
	 */
	public function single_template( $template ) {		
		global $post;
		
		$single_template = wpsight_locate_template( 'single-listing.php' );

		if ( $post->post_type == $this->post_type() && $single_template )
			$template = $single_template;
		
		return $template;
		
	}
	
	/**
	 *	remove_post_type_and_taxonomies()
	 *
	 *  Remove plugin post type and some taxonomies.
	 *
	 *	@uses	wpsight_unregister_post_type()
	 *	@uses	wpsight_unregister_taxonomy()
	 *
	 *	@since 1.0.0
	 */
	public function remove_post_type_and_taxonomies() {
		
		// We use property instead of listing
		wpsight_unregister_post_type( 'listing' );
		
		// We use property-type instead of listing-type
		wpsight_unregister_taxonomy( 'listing-type' );
		
		// We use property-category instead of listing-category
		wpsight_unregister_taxonomy( 'listing-category' );
		
	}
	
	/**
	 *	register_post_type_property()
	 *	
	 *	This functions adds the custom post type listing
	 *	and all the corresponding taxonomies.
 	 *	
 	 *	@access public
 	 *	@uses	apply_filters()
 	 *	@uses	register_taxonomy()
 	 *	@uses	wpsight_post_type()
 	 *	@uses	register_post_type()
 	 *	
 	 *	@since 1.0.0
	 */
	public function register_post_type_property() {
	
		// Custom admin capability
		$admin_capability = 'edit_listings';
	
		// Set labels and localize them
		
		$types_name		= apply_filters( 'wpsight_taxonomy_types_name', __( 'Property Types', 'wpcasa-legacy' ) );
		$types_singular	= apply_filters( 'wpsight_taxonomy_types_singular', __( 'Property Type', 'wpcasa-legacy' ) );
		
		$types_labels = array(
			'name' 						 => $types_name,
			'singular_name' 			 => $types_singular,
			'menu_name' 		 		 => _x( 'Property Types', 'taxonomy types', 'wpcasa-legacy' ),
	        'all_items' 		 		 => _x( 'All Property Types', 'taxonomy types', 'wpcasa-legacy' ),
	        'edit_item' 		 		 => _x( 'Edit Property Type', 'taxonomy types', 'wpcasa-legacy' ),
	        'view_item' 		 		 => _x( 'View Property Type', 'taxonomy types', 'wpcasa-legacy' ),
	        'update_item' 		 		 => _x( 'Update Property Type', 'taxonomy types', 'wpcasa-legacy' ),
	        'add_new_item' 		 		 => _x( 'Add New Property Type', 'taxonomy types', 'wpcasa-legacy' ),
	        'new_item_name' 	 		 => _x( 'New Property Type Name', 'taxonomy types', 'wpcasa-legacy' ),
	        'parent_item'  		 		 => _x( 'Parent Property Type', 'taxonomy types', 'wpcasa-legacy' ),
	        'parent_item_colon'  		 => _x( 'Parent Property Type:', 'taxonomy types', 'wpcasa-legacy' ),
	        'search_items' 		 		 => _x( 'Search Property Types', 'taxonomy types', 'wpcasa-legacy' ),
	        'popular_items' 	 		 => _x( 'Popular Property Types', 'taxonomy types', 'wpcasa-legacy' ),
	        'separate_items_with_commas' => _x( 'Separate property types with commas', 'taxonomy types', 'wpcasa-legacy' ),
	        'add_or_remove_items' 		 => _x( 'Add or remove property types', 'taxonomy types', 'wpcasa-legacy' ),
	        'choose_from_most_used' 	 => _x( 'Choose from the most used property types', 'taxonomy types', 'wpcasa-legacy' ),
	        'not_found' 		 		 => _x( 'No property type found', 'taxonomy types', 'wpcasa-legacy' )
		);
		
		// Set args and rewrite rules
	
		$types_args = array(
			'labels' 	   => $types_labels,
			'hierarchical' => false,
			'capabilities'  => array(
				'manage_terms' => 'manage_listing_terms',
	            'edit_terms'   => 'edit_listing_terms',
	            'delete_terms' => 'delete_listing_terms',
				'assign_terms' => 'assign_listing_terms'
			),
			'rewrite' 	   => array( 
				'slug' 		 => apply_filters( 'wpsight_rewrite_types_slug', 'type' ),
				'with_front' => false
			)
		);
		
		$types_args = apply_filters( 'wpsight_taxonomy_types_args', $types_args );
		
		// Register taxonomy		
		register_taxonomy( 'property-type', array( wpsight_post_type() ), $types_args );
	
		// Set labels and localize them
		
		$categories_name	 = apply_filters( 'wpsight_taxonomy_categories_name', __( 'Categories', 'wpcasa-legacy' ) );
		$categories_singular = apply_filters( 'wpsight_taxonomy_categories_singular', __( 'Category', 'wpcasa-legacy' ) );	
		
		$categories_labels = array(
			'name' 			=> $categories_name,
			'singular_name' => $categories_singular
		);
		
		// Set args and rewrite rules
	
		$categories_args = array(
			'labels' 	   => $categories_labels,
			'hierarchical' => true,
			'capabilities'  => array(
				'manage_terms' => 'manage_listing_terms',
	            'edit_terms'   => 'edit_listing_terms',
	            'delete_terms' => 'delete_listing_terms',
				'assign_terms' => 'assign_listing_terms'
			),
			'rewrite' 	   => array( 
				'slug' 		   => apply_filters( 'wpsight_rewrite_categories_slug', 'property-category' ), 
				'with_front'   => false,
				'hierarchical' => true
			)
		);
		
		$categories_args = apply_filters( 'wpsight_taxonomy_categories_args', $categories_args );
		
		// Register taxonomy		
		register_taxonomy( 'property-category', array( wpsight_post_type() ), $categories_args );
		
		// Set post type labels

		$labels = array( 
		    'name' 				 => _x( 'Properties', 'listing', 'wpcasa-legacy' ),
		    'singular_name' 	 => _x( 'Property', 'listing', 'wpcasa-legacy' ),
		    'add_new' 			 => _x( 'Add New', 'listing', 'wpcasa-legacy' ),
		    'add_new_item' 		 => _x( 'Add New Property', 'listing', 'wpcasa-legacy' ),
		    'edit_item' 		 => _x( 'Edit Property', 'listing', 'wpcasa-legacy' ),
		    'new_item' 			 => _x( 'New Property', 'listing', 'wpcasa-legacy' ),
		    'view_item' 		 => _x( 'View Property', 'listing', 'wpcasa-legacy' ),
		    'search_items' 		 => _x( 'Search Properties', 'listing', 'wpcasa-legacy' ),
		    'not_found' 		 => _x( 'No properties found', 'listing', 'wpcasa-legacy' ),
		    'not_found_in_trash' => _x( 'No properties found in Trash', 'listing', 'wpcasa-legacy' ),
		    'menu_name' 		 => _x( 'Properties', 'listing', 'wpcasa-legacy' ),
		);
		
		$labels = apply_filters( 'wpsight_post_type_labels_property', $labels );
		
		// Set post type arguments
		
		$args = array(
			'label'               => _x( 'Properties', 'listing', 'wpcasa-legacy' ),
			'description'         => _x( 'Searchable listings with detailed information about the corresponding item.', 'listing', 'wpcasa-legacy' ),
		    'labels' 			  => $labels,
		    'hierarchical' 		  => false,        
		    'supports' 			  => array( 'title', 'editor', 'author', 'thumbnail', 'custom-fields', 'revisions', 'excerpt' ),
		    'public' 			  => true,
		    'show_ui' 			  => true,
		    'show_in_menu' 		  => true,
		    'show_in_nav_menus'   => true,
			'menu_position' 	  => 50,
		    'menu_icon'			  => 'dashicons-location',
		    'publicly_queryable'  => true,
		    'exclude_from_search' => false,
		    'has_archive' 		  => true,
		    'query_var' 		  => true,
		    'can_export' 		  => true,
		    'rewrite' 			  => array( 'slug' => apply_filters( 'wpsight_rewrite_listings_slug', 'property' ), 'with_front' => false ),
		    'capability_type' 	  => array( 'listing', 'listings' ),
		    'map_meta_cap'		  => true
		);
		
		$args = apply_filters( 'wpsight_post_type_args_property', $args );
		
		// Register post type		
		register_post_type( 'property', $args );
    	
	}

}
