<?php
/*
Plugin Name: WPCasa Legacy
Plugin URI: https://wpcasa.com/account/submit-ticket/
Description: Add better backward compatibility for WPCasa theme version.
Version: 1.0.0
Author: WPSight
Author URI: http://wpsight.com
Requires at least: 4.0
Tested up to: 4.4.1
Text Domain: wpcasa-legacy
Domain Path: /languages
*/

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) )
	exit;

/**
 * WPCasa_Legacy class
 */
class WPCasa_Legacy {

	/**
	 * Constructor
	 */
	public function __construct() {

		// Define constants
		
		if ( ! defined( 'WPSIGHT_NAME' ) )
			define( 'WPSIGHT_NAME', 'WPCasa' );

		if ( ! defined( 'WPSIGHT_DOMAIN' ) )
			define( 'WPSIGHT_DOMAIN', 'wpcasa' );

		define( 'WPSIGHT_LEGACY_NAME', 'WPCasa Legacy' );
		define( 'WPSIGHT_LEGACY_DOMAIN', 'wpcasa-legacy' );
		define( 'WPSIGHT_LEGACY_VERSION', '1.0.0' );
		define( 'WPSIGHT_LEGACY_PLUGIN_DIR', untrailingslashit( plugin_dir_path( __FILE__ ) ) );
		define( 'WPSIGHT_LEGACY_PLUGIN_URL', untrailingslashit( plugins_url( basename( plugin_dir_path( __FILE__ ) ), basename( __FILE__ ) ) ) );
		
		// Include classes
		include( WPSIGHT_LEGACY_PLUGIN_DIR . '/includes/class-wpcasa-legacy-post-types.php' );
		include( WPSIGHT_LEGACY_PLUGIN_DIR . '/includes/class-wpcasa-legacy-filters.php' );
		
		// Include functions
		include( 'wpcasa-legacy-functions.php' );

		if ( is_admin() ){
			include( WPSIGHT_LEGACY_PLUGIN_DIR . '/includes/admin/class-wpcasa-legacy-admin.php' );
			$this->admin = new WPCasa_Legacy_Admin();
		}
		
		// Init classes
		$this->post_types	= new WPCasa_Legacy_Post_Type_Property();
		$this->filters		= new WPCasa_Legacy_Filters();

		// Actions		
		add_action( 'init', array( $this, 'load_plugin_textdomain' ) );

	}

	/**
	 *	init()
	 *
	 *  Initialize the plugin when WPCasa is loaded
	 *
	 *  @param  object  $wpsight
	 *	@uses	do_action_ref_array()
	 *  @return object
	 *
	 *	@since 1.0.0
	 */
	public static function init( $wpsight ) {
		if ( ! isset( $wpsight->legacy ) ) {
			$wpsight->legacy = new self();
		}
		
		do_action_ref_array( 'wpsight_init_legacy', array( &$wpsight ) );

		return $wpsight->legacy;
	}

	/**
	 *	load_plugin_textdomain()
	 *	
	 *	Set up localization for this plugin
	 *	loading the text domain.
	 *	
	 *	@uses	load_plugin_textdomain()
	 *	
	 *	@since 1.0.0
	 */

	public function load_plugin_textdomain() {
		load_plugin_textdomain( 'wpcasa-legacy', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
	}
	
}

// Initialize plugin on wpsight_init
add_action( 'wpsight_init', array( 'WPCasa_Legacy', 'init' ) );
